==> haskell-primitive-unaligned-0.1.1.2-107-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-primitive-unaligned.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 primitive-unaligned
version:              0.1.1.2
visibility:           public
id:                   primitive-unaligned-0.1.1.2-1CFUmyj6zHqHeOAnMfXaHM
key:                  primitive-unaligned-0.1.1.2-1CFUmyj6zHqHeOAnMfXaHM
license:              BSD-3-Clause
copyright:            2019 Andrew Martin
maintainer:           Andrew Martin <andrew.thaddeus@gmail.com>
author:               Andrew Martin
homepage:             https://github.com/haskell-primitive/primitive-unaligned
synopsis:             Unaligned access to primitive arrays
description:
    Unaligned access to primitive arrays. The offsets are given in bytes rather than elements.

category:             Data
abi:                  bb84ff90e90ee714cb442dd6db53d281
exposed:              True
exposed-modules:      Data.Primitive.ByteArray.Unaligned
hidden-modules:       Data.Primitive.Unaligned.Mach
import-dirs:          /usr/lib/ghc-9.4.8/site-local/primitive-unaligned-0.1.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/primitive-unaligned-0.1.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/primitive-unaligned-0.1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primitive-unaligned
hs-libraries:         HSprimitive-unaligned-0.1.1.2-1CFUmyj6zHqHeOAnMfXaHM
depends:
    base-4.17.2.1 primitive-0.9.1.0-49xiE5QgfWiA4gs3utiGrq

haddock-interfaces:
    /usr/share/doc/haskell-primitive-unaligned/html/primitive-unaligned.haddock

haddock-html:         /usr/share/doc/haskell-primitive-unaligned/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-primitive-unaligned-0.1.1.2-108-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-primitive-unaligned.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 primitive-unaligned
version:              0.1.1.2
visibility:           public
id:                   primitive-unaligned-0.1.1.2-4Oved1SfmZF2ejjxuqfH0L
key:                  primitive-unaligned-0.1.1.2-4Oved1SfmZF2ejjxuqfH0L
license:              BSD-3-Clause
copyright:            2019 Andrew Martin
maintainer:           Andrew Martin <andrew.thaddeus@gmail.com>
author:               Andrew Martin
homepage:             https://github.com/haskell-primitive/primitive-unaligned
synopsis:             Unaligned access to primitive arrays
description:
    Unaligned access to primitive arrays. The offsets are given in bytes rather than elements.

category:             Data
abi:                  dfb91312123931c7dee9d2f74e3fe212
exposed:              True
exposed-modules:      Data.Primitive.ByteArray.Unaligned
hidden-modules:       Data.Primitive.Unaligned.Mach
import-dirs:          /usr/lib/ghc-9.4.8/site-local/primitive-unaligned-0.1.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/primitive-unaligned-0.1.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/primitive-unaligned-0.1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primitive-unaligned
hs-libraries:         HSprimitive-unaligned-0.1.1.2-4Oved1SfmZF2ejjxuqfH0L
depends:
    base-4.17.2.1 primitive-0.9.1.0-6oaPYJdlxXvFbCd1QkYYcO

haddock-interfaces:
    /usr/share/doc/haskell-primitive-unaligned/html/primitive-unaligned.haddock

haddock-html:         /usr/share/doc/haskell-primitive-unaligned/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
